@@ -3,12 +3,12 @@ package histutil
 import (
 	"testing"
 
-	"github.com/elves/elvish/pkg/store"
+	"src.elv.sh/pkg/store/storedefs"
 )
 
 func TestMemStore_Cursor(t *testing.T) {
 	s := NewMemStore("+ 0", "- 1", "+ 2")
-	testCursorIteration(t, s.Cursor("+"), []store.Cmd{
+	testCursorIteration(t, s.Cursor("+"), []storedefs.Cmd{
 		{Text: "+ 0", Seq: 0},
 		{Text: "+ 2", Seq: 2},
 	})
