@@ -6,18 +6,19 @@ import (
 	"src.elv.sh/pkg/eval"
 	. "src.elv.sh/pkg/eval/evaltest"
 	"src.elv.sh/pkg/parse"
+	"src.elv.sh/pkg/ui"
 )
 
 func setupCompleteGetopt(ev *eval.Evaler) {
 	ev.ExtendBuiltin(eval.BuildNs().AddGoFn("complete-getopt", completeGetopt))
 
 	code := `fn complete {|@args|
-	           opt-specs = [ [&short=a &long=all &desc="Show all"]
-	                         [&short=n &long=name &desc="Set name"
-	                          &arg-required=$true &arg-desc='new-name'
-	                          &completer= {|_| put name1 name2 }] ]
-	           arg-handlers = [ {|_| put first1 first2 }
-	                            {|_| put second1 second2 } ... ]
+	           var opt-specs = [ [&short=a &long=all &desc="Show all"]
+	                             [&short=n &long=name &desc="Set name"
+	                              &arg-required=$true &arg-desc='new-name'
+	                              &completer= {|_| put name1 name2 }] ]
+	           var arg-handlers = [ {|_| put first1 first2 }
+	                                {|_| put second1 second2 } ... ]
 	           complete-getopt $args $opt-specs $arg-handlers
 	         }`
 	ev.Eval(parse.Source{Name: "[test init]", Code: code}, eval.EvalCfg{})
@@ -27,43 +28,43 @@ func TestCompleteGetopt(t *testing.T) {
 	TestWithSetup(t, setupCompleteGetopt,
 		// Complete argument
 		That("complete ''").Puts("first1", "first2"),
-		That("complete '' >&-").Throws(eval.ErrNoValueOutput),
+		That("complete '' >&-").Throws(eval.ErrPortDoesNotSupportValueOutput),
 
 		// Complete option
 		That("complete -").Puts(
-			complexItem{Stem: "-a", Display: "-a (Show all)"},
-			complexItem{Stem: "--all", Display: "--all (Show all)"},
-			complexItem{Stem: "-n", Display: "-n new-name (Set name)"},
-			complexItem{Stem: "--name", Display: "--name new-name (Set name)"}),
-		That("complete - >&-").Throws(eval.ErrNoValueOutput),
+			complexItem{Stem: "-a", Display: ui.T("-a (Show all)")},
+			complexItem{Stem: "--all", Display: ui.T("--all (Show all)")},
+			complexItem{Stem: "-n", Display: ui.T("-n new-name (Set name)")},
+			complexItem{Stem: "--name", Display: ui.T("--name new-name (Set name)")}),
+		That("complete - >&-").Throws(eval.ErrPortDoesNotSupportValueOutput),
 
 		// Complete long option
 		That("complete --").Puts(
-			complexItem{Stem: "--all", Display: "--all (Show all)"},
-			complexItem{Stem: "--name", Display: "--name new-name (Set name)"}),
+			complexItem{Stem: "--all", Display: ui.T("--all (Show all)")},
+			complexItem{Stem: "--name", Display: ui.T("--name new-name (Set name)")}),
 		That("complete --a").Puts(
-			complexItem{Stem: "--all", Display: "--all (Show all)"}),
-		That("complete -- >&-").Throws(eval.ErrNoValueOutput),
+			complexItem{Stem: "--all", Display: ui.T("--all (Show all)")}),
+		That("complete -- >&-").Throws(eval.ErrPortDoesNotSupportValueOutput),
 
 		// Complete argument of short option
 		That("complete -n ''").Puts("name1", "name2"),
-		That("complete -n '' >&-").Throws(eval.ErrNoValueOutput),
+		That("complete -n '' >&-").Throws(eval.ErrPortDoesNotSupportValueOutput),
 
 		// Complete argument of long option
 		That("complete --name ''").Puts("name1", "name2"),
-		That("complete --name '' >&-").Throws(eval.ErrNoValueOutput),
+		That("complete --name '' >&-").Throws(eval.ErrPortDoesNotSupportValueOutput),
 
 		// Complete (normal) argument after option that doesn't take an argument
 		That("complete -a ''").Puts("first1", "first2"),
-		That("complete -a '' >&-").Throws(eval.ErrNoValueOutput),
+		That("complete -a '' >&-").Throws(eval.ErrPortDoesNotSupportValueOutput),
 
 		// Complete second argument
 		That("complete arg1 ''").Puts("second1", "second2"),
-		That("complete arg1 '' >&-").Throws(eval.ErrNoValueOutput),
+		That("complete arg1 '' >&-").Throws(eval.ErrPortDoesNotSupportValueOutput),
 
 		// Complete variadic argument
 		That("complete arg1 arg2 ''").Puts("second1", "second2"),
-		That("complete arg1 arg2 '' >&-").Throws(eval.ErrNoValueOutput),
+		That("complete arg1 arg2 '' >&-").Throws(eval.ErrPortDoesNotSupportValueOutput),
 	)
 }
 
