@@ -13,7 +13,7 @@ func initMinibuf(ed *Editor, ev *eval.Evaler, nb eval.NsBuilder) {
 	nb.AddNs("minibuf",
 		eval.BuildNsNamed("edit:minibuf").
 			AddVar("binding", bindingVar).
-			AddGoFns(map[string]interface{}{
+			AddGoFns(map[string]any{
 				"start": func() { minibufStart(ed, ev, bindings) },
 			}))
 }
@@ -44,6 +44,6 @@ func minibufSubmit(ed *Editor, ev *eval.Evaler) {
 	ports := []*eval.Port{eval.DummyInputPort, notifyPort, notifyPort}
 	err := ev.Eval(src, eval.EvalCfg{Ports: ports})
 	if err != nil {
-		app.Notify(err.Error())
+		app.Notify(modes.ErrorText(err))
 	}
 }
