@@ -20,6 +20,13 @@ func TestPut(t *testing.T) {
 	)
 }
 
+func TestRepeat(t *testing.T) {
+	Test(t,
+		That(`repeat 4 foo`).Puts("foo", "foo", "foo", "foo"),
+		thatOutputErrorIsBubbled("repeat 1 foo"),
+	)
+}
+
 func TestReadUpto(t *testing.T) {
 	Test(t,
 		That("print abcd | read-upto c").Puts("abc"),
@@ -177,7 +184,7 @@ func TestPrintf(t *testing.T) {
 		That(`printf "%v" abc`).Prints("abc"),
 		That(`printf "%#v" "abc xyz"`).Prints(`'abc xyz'`),
 		That(`printf '%5.3s' 3.1415`).Prints("  3.1"),
-		That(`printf '%5.3s' (float64 3.1415)`).Prints("  3.1"),
+		That(`printf '%5.3s' (num 3.1415)`).Prints("  3.1"),
 
 		That(`printf '%t' $true`).Prints("true"),
 		That(`printf '%t' $nil`).Prints("false"),
@@ -188,7 +195,7 @@ func TestPrintf(t *testing.T) {
 		That(`printf '%08b' 5`).Prints("00000101"),
 
 		That(`printf '%.1f' 3.1415`).Prints("3.1"),
-		That(`printf '%.1f' (float64 3.1415)`).Prints("3.1"),
+		That(`printf '%.1f' (num 3.1415)`).Prints("3.1"),
 
 		// Does not interpret escape sequences
 		That(`printf '%s\n%s\n' abc xyz`).Prints("abc\\nxyz\\n"),
@@ -207,5 +214,5 @@ func TestPrintf(t *testing.T) {
 }
 
 func thatOutputErrorIsBubbled(code string) Case {
-	return That(code + " >&-").Throws(OneOfErrors(os.ErrInvalid, eval.ErrNoValueOutput))
+	return That(code + " >&-").Throws(OneOfErrors(os.ErrInvalid, eval.ErrPortDoesNotSupportValueOutput))
 }
