@@ -2,6 +2,7 @@ package eval_test
 
 import (
 	"errors"
+	"path/filepath"
 	"testing"
 
 	"src.elv.sh/pkg/diag"
@@ -9,20 +10,21 @@ import (
 	"src.elv.sh/pkg/eval/errs"
 	"src.elv.sh/pkg/eval/vals"
 	"src.elv.sh/pkg/eval/vars"
+	"src.elv.sh/pkg/must"
 	"src.elv.sh/pkg/parse"
-	"src.elv.sh/pkg/prog/progtest"
+	"src.elv.sh/pkg/prog"
+	"src.elv.sh/pkg/testutil"
 
 	. "src.elv.sh/pkg/eval/evaltest"
-	. "src.elv.sh/pkg/testutil"
 )
 
 func TestPragma(t *testing.T) {
 	Test(t,
-		That("pragma unknown-command").DoesNotCompile(),
-		That("pragma unknown-command =").DoesNotCompile(),
-		That("pragma unknown-command x").DoesNotCompile(),
-		That("pragma bad-name = some-value").DoesNotCompile(),
-		That("pragma unknown-command = bad").DoesNotCompile(),
+		That("pragma unknown-command").DoesNotCompile("need literal ="),
+		That("pragma unknown-command =").DoesNotCompile("need pragma value"),
+		That("pragma unknown-command x").DoesNotCompile("must be literal ="),
+		That("pragma bad-name = some-value").DoesNotCompile("unknown pragma bad-name"),
+		That("pragma unknown-command = bad").DoesNotCompile("invalid value for unknown-command: bad"),
 	)
 	// Actual effect of the unknown-command pragma is tested in TestCommand_External
 }
@@ -41,6 +43,7 @@ func TestVar(t *testing.T) {
 		// Declaring a variable whose name ends in "~" initializes it to the
 		// builtin nop function.
 		That("var cmd~; cmd &ignored-opt ignored-arg").DoesNothing(),
+		That("var cmd~; is $cmd~ $nop~").Puts(true),
 		// Declaring multiple variables
 		That("var x y", "put $x $y").Puts(nil, nil),
 		// Declaring one variable with initial value
@@ -78,16 +81,20 @@ func TestVar(t *testing.T) {
 				ValidLow: 2, ValidHigh: -1, Actual: 1},
 			"var x y @z = 1"),
 
+		// Variable name must not be empty
+		That("var ''").DoesNotCompile("variable name must not be empty"),
 		// Variable name that must be quoted after $ must be quoted
-		That("var a/b").DoesNotCompile(),
+		That("var a/b").DoesNotCompile("lvalue must be valid literal variable names"),
 		// Multiple @ not allowed
-		That("var x @y @z = a b c d").DoesNotCompile(),
+		That("var x @y @z = a b c d").DoesNotCompile("at most one rest variable is allowed"),
 		// Non-local not allowed
-		That("var ns:a").DoesNotCompile(),
+		That("var ns:a").DoesNotCompile("cannot create variable $ns:a; new variables can only be created in the current scope"),
 		// Index not allowed
-		That("var a[0]").DoesNotCompile(),
+		That("var a[0]").DoesNotCompile("new variable $a must not have indices"),
 		// Composite expression not allowed
-		That("var a'b'").DoesNotCompile(),
+		That("var a'b'").DoesNotCompile("lvalue may not be composite expressions"),
+		// Braced lists must not have any indices when used as a lvalue.
+		That("var {a b}[0] = x y").DoesNotCompile("braced list may not have indices when used as lvalue"),
 	)
 }
 
@@ -98,12 +105,12 @@ func TestSet(t *testing.T) {
 		// An empty RHS is technically legal although rarely useful.
 		That("var x; set @x =", "put $x").Puts(vals.EmptyList),
 		// Variable must already exist
-		That("set x = foo").DoesNotCompile(),
+		That("set x = foo").DoesNotCompile("cannot find variable $x"),
 		// List element assignment
 		That("var li = [foo bar]; set li[0] = 233; put $@li").Puts("233", "bar"),
 		// Variable in list assignment must already be defined. Regression test
 		// for b.elv.sh/889.
-		That("set foobarlorem[0] = a").DoesNotCompile(),
+		That("set y[0] = a").DoesNotCompile("cannot find variable $y"),
 		// Map element assignment
 		That("var di = [&k=v]; set di[k] = lorem; set di[k2] = ipsum",
 			"put $di[k] $di[k2]").Puts("lorem", "ipsum"),
@@ -117,16 +124,20 @@ func TestSet(t *testing.T) {
 				ValidLow: "0", ValidHigh: "0", Actual: "1"}, "li[1][2]"),
 
 		// Assignment to read-only var is a compile-time error.
-		That("set nil = 1").DoesNotCompile(),
-		That("var a b; set a true b = 1 2 3").DoesNotCompile(),
-		That("set @true = 1").DoesNotCompile(),
-		That("var r; set true @r = 1").DoesNotCompile(),
-		That("var r; set @r true = 1").DoesNotCompile(),
+		That("set nil = 1").DoesNotCompile("variable $nil is read-only"),
+		That("var a b; set a true b = 1 2 3").DoesNotCompile("variable $true is read-only"),
+		That("set @true = 1").DoesNotCompile("variable $true is read-only"),
+		That("var r; set true @r = 1").DoesNotCompile("variable $true is read-only"),
+		That("var r; set @r true = 1").DoesNotCompile("variable $true is read-only"),
 
 		// Error conditions already covered by TestVar are not repeated.
 
 		// = is required.
-		That("var x; set x").DoesNotCompile(),
+		That("var x; set x").DoesNotCompile("need = and right-hand-side"),
+
+		// set a non-exist environment
+		That("has-env X; set E:X = x; get-env X; unset-env X").
+			Puts(false, "x"),
 	)
 }
 
@@ -140,12 +151,19 @@ func TestSet_ErrorInSetMethod(t *testing.T) {
 }
 
 func TestTmp(t *testing.T) {
+	testutil.Unsetenv(t, "X")
+
 	Test(t,
 		That("var x = foo; put $x; { tmp x = bar; put $x }; put $x").
 			Puts("foo", "bar", "foo"),
 
-		That("var x; tmp x = y").DoesNotCompile(),
-		That("{ tmp x = y }").DoesNotCompile(),
+		That("var x; tmp x = y").DoesNotCompile("tmp may only be used inside a function"),
+		That("{ tmp x = y }").DoesNotCompile("cannot find variable $x"),
+
+		That("has-env X; { tmp E:X = y; put $E:X }; has-env X; put $E:X").
+			Puts(false, "y", false, ""),
+		That("set-env X x; { tmp E:X = y; put $E:X }; get-env X; put $E:X; unset-env X").
+			Puts("y", "x", "x"),
 	)
 }
 
@@ -172,9 +190,9 @@ var errBadVar = errors.New("bad var")
 
 type badVar struct{ allowedSets int }
 
-func (v *badVar) Get() interface{} { return nil }
+func (v *badVar) Get() any { return nil }
 
-func (v *badVar) Set(interface{}) error {
+func (v *badVar) Set(any) error {
 	if v.allowedSets == 0 {
 		return errBadVar
 	}
@@ -183,12 +201,12 @@ func (v *badVar) Set(interface{}) error {
 }
 
 func TestDel(t *testing.T) {
-	Setenv(t, "TEST_ENV", "test value")
+	testutil.Setenv(t, "TEST_ENV", "test value")
 
 	Test(t,
 		// Deleting variable
 		That("var x = 1; del x").DoesNothing(),
-		That("var x = 1; del x; echo $x").DoesNotCompile(),
+		That("var x = 1; del x; echo $x").DoesNotCompile("variable $x not found"),
 		// Deleting environment variable
 		That("has-env TEST_ENV", "del E:TEST_ENV", "has-env TEST_ENV").Puts(true, false),
 		// Deleting variable whose name contains special characters
@@ -200,21 +218,21 @@ func TestDel(t *testing.T) {
 		// Error cases
 
 		// Deleting nonexistent variable
-		That("del x").DoesNotCompile(),
+		That("del x").DoesNotCompile("no variable $x"),
 		// Deleting element of nonexistent variable
-		That("del x[0]").DoesNotCompile(),
+		That("del x[0]").DoesNotCompile("no variable $x"),
 		// Deleting variable in non-local namespace
-		That("var a: = (ns [&b=$nil])", "del a:b").DoesNotCompile(),
+		That("var a: = (ns [&b=$nil])", "del a:b").DoesNotCompile("only variables in the local scope or E: can be deleted"),
 		// Variable name given with $
-		That("var x = 1; del $x").DoesNotCompile(),
+		That("var x = 1; del $x").DoesNotCompile("arguments to del must omit the dollar sign"),
 		// Variable name not given as a single primary expression
-		That("var ab = 1; del a'b'").DoesNotCompile(),
+		That("var ab = 1; del a'b'").DoesNotCompile("arguments to del must be variable or variable elements"),
 		// Variable name not a string
-		That("del [a]").DoesNotCompile(),
+		That("del [a]").DoesNotCompile("arguments to del must be variable or variable elements"),
 		// Variable name has sigil
-		That("var x = []; del @x").DoesNotCompile(),
+		That("var x = []; del @x").DoesNotCompile("arguments to del must be variable or variable elements"),
 		// Variable name not quoted when it should be
-		That("var 'a/b' = foo; del a/b").DoesNotCompile(),
+		That("var 'a/b' = foo; del a/b").DoesNotCompile("arguments to del must be variable or variable elements"),
 
 		// Index is multiple values
 		That("var x = [&k1=v1 &k2=v2]", "del x[k1 k2]").Throws(
@@ -283,8 +301,8 @@ func TestCoalesce(t *testing.T) {
 func TestSpecialFormThunks(t *testing.T) {
 	// Regression test for b.elv.sh/1456
 	Test(t,
-		That("for x [] {|arg| }").DoesNotCompile(),
-		That("for x [] {|&opt=val| }").DoesNotCompile(),
+		That("for x [] {|arg| }").DoesNotCompile("for body must not have arguments"),
+		That("for x [] {|&opt=val| }").DoesNotCompile("for body must not have options"),
 		// The other special forms use the same utility under the hood and are
 		// not repeated
 	)
@@ -323,28 +341,25 @@ func TestTry(t *testing.T) {
 		That("try { fail tr } catch { fail ex } finally { fail final }").
 			Throws(ErrorWithMessage("final")),
 
-		// except is a deprecated synonym for catch
-		That("try { fail tr } except { put bad }").Puts("bad"),
 		// Must have catch or finally
-		That("try { fail tr }").DoesNotCompile(),
+		That("try { fail tr }").DoesNotCompile("try must be followed by a catch block or a finally block"),
 		// Rest variable not allowed
-		That("try { nop } catch @a { }").DoesNotCompile(),
+		That("try { nop } catch @a { }").DoesNotCompile("rest variable not allowed"),
 
 		// A readonly var as a target for the "catch" clause is a compile-time
 		// error.
-		That("try { fail reason } catch nil { }").DoesNotCompile(),
+		That("try { fail reason } catch nil { }").DoesNotCompile("variable $nil is read-only"),
 		That("try { fail reason } catch x { }").DoesNothing(),
 
 		// A quoted var name, that would be invalid as a bareword, should be allowed as the referent
-		// in a `try...except...` block.
+		// in a `try...catch...` block.
 		That("try { fail hard } catch 'x=' { put 'x= ='(to-string $'x=') }").
-			Puts("x= =[&reason=[&content=hard &type=fail]]"),
-	)
-}
+			Puts("x= =[&reason=[&content=hard &type=fail] &stack-trace=<...>]"),
 
-func TestTry_ExceptIsDeprecated(t *testing.T) {
-	testCompileTimeDeprecation(t, "try { } except { }",
-		`"except" is deprecated; use "catch" instead`, 18)
+		// Regression test: "try { } catch" is a syntax error, but it should not
+		// panic.
+		That("try { } catch").DoesNotCompile("need variable or body"),
+	)
 }
 
 func TestWhile(t *testing.T) {
@@ -388,10 +403,10 @@ func TestFor(t *testing.T) {
 		That("for x [a] { fail foo }").Throws(FailError{"foo"}),
 
 		// More than one iterator.
-		That("for {x,y} [] { }").DoesNotCompile(),
+		That("for {x,y} [] { }").DoesNotCompile("must be exactly one lvalue"),
 		// Invalid for loop lvalue. You can't use a var in a namespace other
 		// than the local namespace as the lvalue in a for loop.
-		That("for no-such-namespace:x [a b] { }").DoesNotCompile(),
+		That("for no-such-namespace:x [a b] { }").DoesNotCompile("cannot create variable $no-such-namespace:x; new variables can only be created in the current scope"),
 		// Exception with the variable
 		That("var a: = (ns [&])", "for a:b [] { }").Throws(
 			ErrorWithMessage("no variable $a:b"),
@@ -425,9 +440,9 @@ func TestFn(t *testing.T) {
 
 // Regression test for #1225
 func TestUse_SetsVariableCorrectlyIfModuleCallsExtendGlobal(t *testing.T) {
-	libdir := InTempDir(t)
+	libdir := testutil.InTempDir(t)
 
-	ApplyDir(Dir{"a.elv": "add-var"})
+	testutil.ApplyDir(testutil.Dir{"a.elv": "add-var"})
 	ev := NewEvaler()
 	ev.LibDirs = []string{libdir}
 	addVar := func() {
@@ -435,7 +450,7 @@ func TestUse_SetsVariableCorrectlyIfModuleCallsExtendGlobal(t *testing.T) {
 	}
 	ev.ExtendBuiltin(BuildNs().AddGoFn("add-var", addVar))
 
-	err := ev.Eval(parse.Source{Code: "use a"}, EvalCfg{})
+	err := ev.Eval(parse.Source{Name: "[test]", Code: "use a"}, EvalCfg{})
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -450,8 +465,8 @@ func TestUse_SetsVariableCorrectlyIfModuleCallsExtendGlobal(t *testing.T) {
 }
 
 func TestUse_SupportsCircularDependency(t *testing.T) {
-	libdir := InTempDir(t)
-	ApplyDir(Dir{
+	libdir := testutil.InTempDir(t)
+	testutil.ApplyDir(testutil.Dir{
 		"a.elv": "var pre = apre; use b; put $b:pre $b:post; var post = apost",
 		"b.elv": "var pre = bpre; use a; put $a:pre $a:post; var post = bpost",
 	})
@@ -467,21 +482,22 @@ func TestUse_SupportsCircularDependency(t *testing.T) {
 }
 
 func TestUse(t *testing.T) {
-	libdir1 := InTempDir(t)
-	ApplyDir(Dir{
-		"shadow.elv": "put lib1",
+	libdir1 := testutil.InTempDir(t)
+	testutil.ApplyDir(testutil.Dir{
+		"shadow.elv":       "put lib1",
+		"invalid-utf8.elv": "\xff",
 	})
 
-	libdir2 := InTempDir(t)
-	ApplyDir(Dir{
+	libdir2 := testutil.InTempDir(t)
+	testutil.ApplyDir(testutil.Dir{
 		"has-init.elv": "put has-init",
 		"put-x.elv":    "put $x",
 		"lorem.elv":    "var name = lorem; fn put-name { put $name }",
 		"d.elv":        "var name = d",
 		"shadow.elv":   "put lib2",
-		"a": Dir{
-			"b": Dir{
-				"c": Dir{
+		"a": testutil.Dir{
+			"b": testutil.Dir{
+				"c": testutil.Dir{
 					"d.elv": "var name = a/b/c/d",
 					"x.elv": "use ./d; var d = $d:name; use ../../../lorem; var lorem = $lorem:name",
 				},
@@ -493,7 +509,7 @@ func TestUse(t *testing.T) {
 		That(`use lorem; put $lorem:name`).Puts("lorem"),
 		// imports are lexically scoped
 		// TODO: Support testing for compilation error
-		That(`{ use lorem }; put $lorem:name`).DoesNotCompile(),
+		That(`{ use lorem }; put $lorem:name`).DoesNotCompile("variable $lorem:name not found"),
 
 		// prefers lib dir that appear earlier
 		That("use shadow").Puts("lib1"),
@@ -532,20 +548,24 @@ func TestUse(t *testing.T) {
 		That("use ./unknown").Throws(ErrorWithType(NoSuchModule{})),
 		That("use ../unknown").Throws(ErrorWithType(NoSuchModule{})),
 
+		// Invalid UTF-8 in module file
+		That("use invalid-utf8").Throws(ErrorWithMessage(
+			filepath.Join(libdir1, "invalid-utf8.elv")+": source is not valid UTF-8")),
+
 		// Nonexistent module
 		That("use non-existent").Throws(ErrorWithMessage("no such module: non-existent")),
 
 		// Wrong uses of "use".
-		That("use").DoesNotCompile(),
-		That("use a b c").DoesNotCompile(),
+		That("use").DoesNotCompile("need module spec"),
+		That("use a b c").DoesNotCompile("superfluous arguments"),
 	)
 }
 
 // Regression test for #1072
 func TestUse_WarnsAboutDeprecatedFeatures(t *testing.T) {
-	progtest.SetDeprecationLevel(t, 18)
-	libdir := InTempDir(t)
-	MustWriteFile("dep.elv", "a=b nop $a")
+	testutil.Set(t, &prog.DeprecationLevel, 18)
+	libdir := testutil.InTempDir(t)
+	must.WriteFile("dep.elv", "a=b nop $a")
 
 	TestWithSetup(t, func(ev *Evaler) { ev.LibDirs = []string{libdir} },
 		// Importing module triggers check for deprecated features
