@@ -72,7 +72,7 @@ func (op *pipelineOp) exec(fm *Frame) Exception {
 	}
 
 	if op.bg {
-		fm = fm.fork("background job" + op.source)
+		fm = fm.Fork("background job" + op.source)
 		fm.intCh = nil
 		fm.background = true
 		fm.Evaler.addNumBgJobs(1)
@@ -88,7 +88,7 @@ func (op *pipelineOp) exec(fm *Frame) Exception {
 
 	// For each form, create a dedicated evalCtx and run asynchronously
 	for i, formOp := range op.subops {
-		newFm := fm.fork("[form op]")
+		newFm := fm.Fork("[form op]")
 		inputIsPipe := i > 0
 		outputIsPipe := i < nforms-1
 		if inputIsPipe {
@@ -102,7 +102,7 @@ func (op *pipelineOp) exec(fm *Frame) Exception {
 			if e != nil {
 				return fm.errorpf(op, "failed to create pipe: %s", e)
 			}
-			ch := make(chan interface{}, pipelineChanBufferSize)
+			ch := make(chan any, pipelineChanBufferSize)
 			sendStop := make(chan struct{})
 			sendError := new(error)
 			readerGone := new(int32)
@@ -168,11 +168,15 @@ func (cp *compiler) formOp(n *parse.Form) effectOp {
 	var tempLValues []lvalue
 	var assignmentOps []effectOp
 	if len(n.Assignments) > 0 {
-		assignmentOps = cp.assignmentOps(n.Assignments)
 		if n.Head == nil {
 			cp.errorpf(n, `using the syntax of temporary assignment for non-temporary assignment is no longer supported; use "var" or "set" instead`)
 			return nopOp{}
+		} else {
+			as := n.Assignments
+			cp.deprecate(diag.MixedRanging(as[0], as[len(as)-1]),
+				`the legacy temporary assignment syntax is deprecated; use "tmp" instead`, 18)
 		}
+		assignmentOps = cp.assignmentOps(n.Assignments)
 		for _, a := range n.Assignments {
 			lvalues := cp.parseIndexingLValue(a.Left, setLValue|newLValue)
 			tempLValues = append(tempLValues, lvalues.lvalues...)
@@ -201,39 +205,19 @@ func (cp *compiler) formBody(n *parse.Form) formBody {
 		}
 	}
 
-	// Determine if the form is a legacy assignment form, by looking for an
-	// argument whose source is a literal "=".
-	for i, arg := range n.Args {
-		if parse.SourceText(arg) == "=" {
-			cp.deprecate(n, "legacy assignment form is deprecated, use var or set instead; migrate scripts with https://go.elv.sh/u0.17", 17)
-			lhsNodes := make([]*parse.Compound, i+1)
-			lhsNodes[0] = n.Head
-			copy(lhsNodes[1:], n.Args[:i])
-			lhs := cp.parseCompoundLValues(lhsNodes, setLValue|newLValue)
-
-			rhsOps := cp.compoundOps(n.Args[i+1:])
-			var rhsRange diag.Ranging
-			if len(rhsOps) > 0 {
-				rhsRange = diag.MixedRanging(rhsOps[0], rhsOps[len(rhsOps)-1])
-			} else {
-				rhsRange = diag.PointRanging(n.Range().To)
-			}
-			rhs := seqValuesOp{rhsRange, rhsOps}
-
-			return formBody{assignOp: &assignOp{n.Range(), lhs, rhs}}
-		}
-	}
-
 	var headOp valuesOp
 	if head, ok := cmpd.StringLiteral(n.Head); ok {
 		// Head is a literal string: resolve to function or external (special
 		// commands are already handled above).
 		if _, fnRef := resolveCmdHeadInternally(cp, head, n.Head); fnRef != nil {
 			headOp = variableOp{n.Head.Range(), false, head + FnSuffix, fnRef}
-		} else if cp.currentPragma().unknownCommandIsExternal || fsutil.DontSearch(head) {
-			headOp = literalValues(n.Head, NewExternalCmd(head))
 		} else {
-			cp.errorpf(n.Head, "unknown command disallowed by current pragma")
+			cp.autofixUnresolvedVar(head + FnSuffix)
+			if cp.currentPragma().unknownCommandIsExternal || fsutil.DontSearch(head) {
+				headOp = literalValues(n.Head, NewExternalCmd(head))
+			} else {
+				cp.errorpf(n.Head, "unknown command disallowed by current pragma")
+			}
 		}
 	} else {
 		// Head is not a literal string: evaluate as a normal expression.
@@ -283,7 +267,7 @@ func (op *formOp) exec(fm *Frame) (errRet Exception) {
 		// There is a temporary assignment.
 		// Save variables.
 		var saveVars []vars.Var
-		var saveVals []interface{}
+		var saveVals []any
 		for _, lv := range op.tempLValues {
 			variable, err := derefLValue(fm, lv)
 			if err != nil {
@@ -357,7 +341,7 @@ func (op *formOp) exec(fm *Frame) (errRet Exception) {
 		return fm.errorp(cmd.headOp, err)
 	}
 
-	var args []interface{}
+	var args []any
 	for _, argOp := range cmd.argOps {
 		moreArgs, exc := argOp.exec(fm)
 		if exc != nil {
@@ -367,8 +351,8 @@ func (op *formOp) exec(fm *Frame) (errRet Exception) {
 	}
 
 	// TODO(xiaq): This conversion should be avoided.
-	convertedOpts := make(map[string]interface{})
-	exc := cmd.optsOp.exec(fm, func(k, v interface{}) Exception {
+	convertedOpts := make(map[string]any)
+	exc := cmd.optsOp.exec(fm, func(k, v any) Exception {
 		if ks, ok := k.(string); ok {
 			convertedOpts[ks] = v
 			return nil
@@ -405,10 +389,10 @@ func evalForCommand(fm *Frame, op valuesOp, what string) (Callable, error) {
 	return nil, fm.errorp(op, errs.BadValue{
 		What:   what,
 		Valid:  "callable or string containing slash",
-		Actual: vals.Repr(value, vals.NoPretty)})
+		Actual: vals.ReprPlain(value)})
 }
 
-func allTrue(vs []interface{}) bool {
+func allTrue(vs []any) bool {
 	for _, v := range vs {
 		if !vals.Bool(v) {
 			return false
@@ -420,7 +404,7 @@ func allTrue(vs []interface{}) bool {
 func (cp *compiler) assignmentOp(n *parse.Assignment) effectOp {
 	lhs := cp.parseIndexingLValue(n.Left, setLValue|newLValue)
 	rhs := cp.compoundOp(n.Right)
-	return &assignOp{n.Range(), lhs, rhs}
+	return &assignOp{n.Range(), lhs, rhs, false}
 }
 
 func (cp *compiler) assignmentOps(ns []*parse.Assignment) []effectOp {
@@ -479,9 +463,9 @@ type redirOp struct {
 	flag    int
 }
 
-type invalidFD struct{ fd int }
+type InvalidFD struct{ FD int }
 
-func (err invalidFD) Error() string { return fmt.Sprintf("invalid fd: %d", err.fd) }
+func (err InvalidFD) Error() string { return fmt.Sprintf("invalid fd: %d", err.FD) }
 
 func (op *redirOp) exec(fm *Frame) Exception {
 	var dst int
@@ -517,9 +501,9 @@ func (op *redirOp) exec(fm *Frame) Exception {
 			// close
 			fm.ports[dst] = &Port{
 				// Ensure that writing to value output throws an exception
-				sendStop: closedSendStop, sendError: &ErrNoValueOutput}
+				sendStop: closedSendStop, sendError: &ErrPortDoesNotSupportValueOutput}
 		case src >= len(fm.ports) || fm.ports[src] == nil:
-			return fm.errorp(op, invalidFD{src})
+			return fm.errorp(op, InvalidFD{FD: src})
 		default:
 			fm.ports[dst] = fm.ports[src].fork()
 		}
@@ -533,7 +517,7 @@ func (op *redirOp) exec(fm *Frame) Exception {
 	case string:
 		f, err := os.OpenFile(src, op.flag, defaultFileRedirPerm)
 		if err != nil {
-			return fm.errorpf(op, "failed to open file %s: %s", vals.Repr(src, vals.NoPretty), err)
+			return fm.errorpf(op, "failed to open file %s: %s", vals.ReprPlain(src), err)
 		}
 		fm.ports[dst] = fileRedirPort(op.mode, f, true)
 	case vals.File:
@@ -571,7 +555,7 @@ func fileRedirPort(mode parse.RedirMode, f *os.File, closeFile bool) *Port {
 	return &Port{
 		File: f, closeFile: closeFile,
 		// Throws errValueOutputIsClosed when writing.
-		Chan: nil, sendStop: closedSendStop, sendError: &ErrNoValueOutput,
+		Chan: nil, sendStop: closedSendStop, sendError: &ErrPortDoesNotSupportValueOutput,
 	}
 }
 
@@ -609,7 +593,7 @@ func evalForFd(fm *Frame, op valuesOp, closeOK bool, what string) (int, error) {
 		valid = "fd name or number or '-'"
 	}
 	return -1, fm.errorp(op, errs.BadValue{
-		What: what, Valid: valid, Actual: vals.Repr(value, vals.NoPretty)})
+		What: what, Valid: valid, Actual: vals.ReprPlain(value)})
 }
 
 type seqOp struct{ subops []effectOp }
