@@ -9,14 +9,11 @@ import (
 	"strconv"
 	"sync"
 
-	"src.elv.sh/pkg/daemon/daemondefs"
-	"src.elv.sh/pkg/diag"
 	"src.elv.sh/pkg/env"
 	"src.elv.sh/pkg/eval/vals"
 	"src.elv.sh/pkg/eval/vars"
 	"src.elv.sh/pkg/logutil"
 	"src.elv.sh/pkg/parse"
-	"src.elv.sh/pkg/persistent/vector"
 )
 
 var logger = logutil.GetLogger("[eval] ")
@@ -35,7 +32,6 @@ const (
 const (
 	defaultValuePrefix        = "▶ "
 	defaultNotifyBgJobSuccess = true
-	initIndent                = vals.NoPretty
 )
 
 // Evaler provides methods for evaluating code, and maintains state that is
@@ -48,11 +44,9 @@ type Evaler struct {
 	// Command-line arguments, exposed as $args.
 	Args vals.List
 	// Hooks to run before exit or exec.
-	BeforeExit []func()
+	PreExitHooks []func()
 	// Chdir hooks, exposed indirectly as $before-chdir and $after-chdir.
 	BeforeChdir, AfterChdir []func(string)
-	// TODO: Remove after the dir-history command is removed.
-	DaemonClient daemondefs.Client
 	// Directories to search libraries.
 	LibDirs []string
 	// Source code of internal bundled modules indexed by use specs.
@@ -60,6 +54,10 @@ type Evaler struct {
 	// Callback to notify the success or failure of background jobs. Must not be
 	// mutated once the Evaler is used to evaluate any code.
 	BgJobNotify func(string)
+	// Path to the rc file, and path to the rc file actually evaluated. These
+	// are not used by the Evaler itself right now; they are here so that they
+	// can be exposed to the runtime: module.
+	RcPath, EffectiveRcPath string
 
 	mu sync.RWMutex
 	// Mutations to fields below must be guarded by mutex.
@@ -89,64 +87,10 @@ type Evaler struct {
 	numBgJobs int
 }
 
-//elvdoc:var after-chdir
-//
-// A list of functions to run after changing directory. These functions are always
-// called with directory to change it, which might be a relative path. The
-// following example also shows `$before-chdir`:
-//
-// ```elvish-transcript
-// ~> before-chdir = [{|dir| echo "Going to change to "$dir", pwd is "$pwd }]
-// ~> after-chdir = [{|dir| echo "Changed to "$dir", pwd is "$pwd }]
-// ~> cd /usr
-// Going to change to /usr, pwd is /Users/xiaq
-// Changed to /usr, pwd is /usr
-// /usr> cd local
-// Going to change to local, pwd is /usr
-// Changed to local, pwd is /usr/local
-// /usr/local>
-// ```
-//
-// @cf before-chdir
-
-//elvdoc:var before-chdir
-//
-// A list of functions to run before changing directory. These functions are always
-// called with the new working directory.
-//
-// @cf after-chdir
-
-//elvdoc:var num-bg-jobs
-//
-// Number of background jobs.
-
-//elvdoc:var notify-bg-job-success
-//
-// Whether to notify success of background jobs, defaulting to `$true`.
-//
-// Failures of background jobs are always notified.
-
-//elvdoc:var value-out-indicator
-//
-// A string put before value outputs (such as those of of `put`). Defaults to
-// `'▶ '`. Example:
-//
-// ```elvish-transcript
-// ~> put lorem ipsum
-// ▶ lorem
-// ▶ ipsum
-// ~> value-out-indicator = 'val> '
-// ~> put lorem ipsum
-// val> lorem
-// val> ipsum
-// ```
-//
-// Note that you almost always want some trailing whitespace for readability.
-
 // NewEvaler creates a new Evaler.
 func NewEvaler() *Evaler {
 	builtin := builtinNs.Ns()
-	beforeChdirElvish, afterChdirElvish := vector.Empty, vector.Empty
+	beforeChdirElvish, afterChdirElvish := vals.EmptyList, vals.EmptyList
 
 	ev := &Evaler{
 		global:  new(Ns),
@@ -177,8 +121,8 @@ func NewEvaler() *Evaler {
 		AddVar("notify-bg-job-success",
 			vars.FromPtrWithMutex(&ev.notifyBgJobSuccess, &ev.mu)).
 		AddVar("num-bg-jobs",
-			vars.FromGet(func() interface{} { return strconv.Itoa(ev.getNumBgJobs()) })).
-		AddVar("args", vars.FromGet(func() interface{} { return ev.Args })))
+			vars.FromGet(func() any { return strconv.Itoa(ev.getNumBgJobs()) })).
+		AddVar("args", vars.FromGet(func() any { return ev.Args })))
 
 	// Install the "builtin" module after extension is complete.
 	ev.modules["builtin"] = ev.builtin
@@ -186,11 +130,11 @@ func NewEvaler() *Evaler {
 	return ev
 }
 
-func adaptChdirHook(name string, ev *Evaler, pfns *vector.Vector) func(string) {
+func adaptChdirHook(name string, ev *Evaler, pfns *vals.List) func(string) {
 	return func(path string) {
 		ports, cleanup := PortsFromStdFiles(ev.ValuePrefix())
 		defer cleanup()
-		callCfg := CallCfg{Args: []interface{}{path}, From: "[hook " + name + "]"}
+		callCfg := CallCfg{Args: []any{path}, From: "[hook " + name + "]"}
 		evalCfg := EvalCfg{Ports: ports[:]}
 		for it := (*pfns).Iterator(); it.HasElem(); it.Next() {
 			fn, ok := it.Elem().(Callable)
@@ -207,6 +151,13 @@ func adaptChdirHook(name string, ev *Evaler, pfns *vector.Vector) func(string) {
 	}
 }
 
+// PreExit runs all pre-exit hooks.
+func (ev *Evaler) PreExit() {
+	for _, hook := range ev.PreExitHooks {
+		hook()
+	}
+}
+
 // Access methods.
 
 // Global returns the global Ns.
@@ -223,6 +174,19 @@ func (ev *Evaler) ExtendGlobal(ns Nser) {
 	ev.global = CombineNs(ev.global, ns.Ns())
 }
 
+// DeleteFromGlobal deletes names from the global namespace.
+func (ev *Evaler) DeleteFromGlobal(names map[string]struct{}) {
+	ev.mu.Lock()
+	defer ev.mu.Unlock()
+	g := ev.global.clone()
+	for i := range g.infos {
+		if _, ok := names[g.infos[i].name]; ok {
+			g.infos[i].deleted = true
+		}
+	}
+	ev.global = g
+}
+
 // Builtin returns the builtin Ns.
 func (ev *Evaler) Builtin() *Ns {
 	ev.mu.RLock()
@@ -237,6 +201,14 @@ func (ev *Evaler) ExtendBuiltin(ns Nser) {
 	ev.builtin = CombineNs(ev.builtin, ns.Ns())
 }
 
+// ReplaceBuiltin replaces the builtin namespace. It should only be used in
+// tests.
+func (ev *Evaler) ReplaceBuiltin(ns *Ns) {
+	ev.mu.Lock()
+	defer ev.mu.Unlock()
+	ev.builtin = ns
+}
+
 func (ev *Evaler) registerDeprecation(d deprecation) bool {
 	ev.mu.Lock()
 	defer ev.mu.Unlock()
@@ -277,32 +249,6 @@ func (ev *Evaler) addNumBgJobs(delta int) {
 	ev.numBgJobs += delta
 }
 
-// SetArgs sets the value of the $args variable to a list of strings, built from
-// the given slice. This method must be called before the Evaler is used to
-// evaluate any code.
-func (ev *Evaler) SetArgs(args []string) {
-	ev.Args = listOfStrings(args)
-}
-
-// AddBeforeChdir adds a function to run before changing directory. This method
-// must be called before the Evaler is used to evaluate any code.
-func (ev *Evaler) AddBeforeChdir(f func(string)) {
-	ev.BeforeChdir = append(ev.BeforeChdir, f)
-}
-
-// AddAfterChdir adds a function to run after changing directory. This method
-// must be called before the Evaler is used to evaluate any code.
-func (ev *Evaler) AddAfterChdir(f func(string)) {
-	ev.AfterChdir = append(ev.AfterChdir, f)
-}
-
-// AddBeforeExit adds a function to run before the Elvish process exits or gets
-// replaced (via "exec" on UNIX). This method must be called before the Evaler
-// is used to evaluate any code.
-func (ev *Evaler) AddBeforeExit(f func()) {
-	ev.BeforeExit = append(ev.BeforeExit, f)
-}
-
 // Chdir changes the current directory, and updates $E:PWD on success
 //
 // It runs the functions in beforeChdir immediately before changing the
@@ -388,7 +334,7 @@ func (ev *Evaler) Eval(src parse.Source, cfg EvalCfg) error {
 		ev.mu.Unlock()
 	}
 
-	op, err := compile(b.static(), cfg.Global.static(), tree, errFile)
+	op, _, err := compile(b.static(), cfg.Global.static(), nil, tree, errFile)
 	if err != nil {
 		if defaultGlobal {
 			ev.mu.Unlock()
@@ -410,10 +356,10 @@ func (ev *Evaler) Eval(src parse.Source, cfg EvalCfg) error {
 
 // CallCfg keeps configuration for the (*Evaler).Call method.
 type CallCfg struct {
-	// Arguments to pass to the the function.
-	Args []interface{}
+	// Arguments to pass to the function.
+	Args []any
 	// Options to pass to the function.
-	Opts map[string]interface{}
+	Opts map[string]any
 	// The name of the internal source that is calling the function.
 	From string
 }
@@ -448,7 +394,7 @@ func (ev *Evaler) prepareFrame(src parse.Source, cfg EvalCfg) (*Frame, func()) {
 
 	ports := fillDefaultDummyPorts(cfg.Ports)
 
-	fm := &Frame{ev, src, cfg.Global, new(Ns), intCh, ports, nil, false}
+	fm := &Frame{ev, src, cfg.Global, new(Ns), nil, intCh, ports, nil, false}
 	return fm, func() {
 		if intChCleanup != nil {
 			intChCleanup()
@@ -477,23 +423,21 @@ func fillDefaultDummyPorts(ports []*Port) []*Port {
 	return ports
 }
 
-// Check checks the given source code for any parse error and compilation error.
-// It always tries to compile the code even if there is a parse error; both
-// return values may be non-nil. If w is not nil, deprecation messages are
-// written to it.
-func (ev *Evaler) Check(src parse.Source, w io.Writer) (*parse.Error, *diag.Error) {
+// Check checks the given source code for any parse error, autofixes, and
+// compilation error. It always tries to compile the code even if there is a
+// parse error. If w is not nil, deprecation messages are written to it.
+func (ev *Evaler) Check(src parse.Source, w io.Writer) (error, []string, error) {
 	tree, parseErr := parse.Parse(src, parse.Config{WarningWriter: w})
-	return parse.GetError(parseErr), ev.CheckTree(tree, w)
+	autofixes, compileErr := ev.CheckTree(tree, w)
+	return parseErr, autofixes, compileErr
 }
 
-// CheckTree checks the given parsed source tree for compilation errors. If w is
-// not nil, deprecation messages are written to it.
-func (ev *Evaler) CheckTree(tree parse.Tree, w io.Writer) *diag.Error {
-	_, compileErr := ev.compile(tree, ev.Global(), w)
-	return GetCompilationError(compileErr)
-}
-
-// Compiles a parsed tree.
-func (ev *Evaler) compile(tree parse.Tree, g *Ns, w io.Writer) (nsOp, error) {
-	return compile(ev.Builtin().static(), g.static(), tree, w)
+// CheckTree checks the given parsed source tree for autofixes and compilation
+// errors. If w is not nil, deprecation messages are written to it.
+func (ev *Evaler) CheckTree(tree parse.Tree, w io.Writer) ([]string, error) {
+	ev.mu.RLock()
+	b, g, m := ev.builtin, ev.global, ev.modules
+	ev.mu.RUnlock()
+	_, autofixes, compileErr := compile(b.static(), g.static(), mapKeys(m), tree, w)
+	return autofixes, compileErr
 }
