@@ -7,20 +7,20 @@ import (
 	"testing"
 	"unsafe"
 
-	"github.com/elves/elvish/pkg/diag"
-	. "github.com/elves/elvish/pkg/eval"
+	"src.elv.sh/pkg/diag"
+	. "src.elv.sh/pkg/eval"
 
-	. "github.com/elves/elvish/pkg/eval/evaltest"
-	"github.com/elves/elvish/pkg/eval/vals"
-	"github.com/elves/elvish/pkg/tt"
-	"github.com/xiaq/persistent/hash"
+	. "src.elv.sh/pkg/eval/evaltest"
+	"src.elv.sh/pkg/eval/vals"
+	"src.elv.sh/pkg/persistent/hash"
+	"src.elv.sh/pkg/tt"
 )
 
 func TestReason(t *testing.T) {
 	err := errors.New("ordinary error")
 	tt.Test(t, tt.Fn("Reason", Reason), tt.Table{
-		tt.Args(err).Rets(err),
-		tt.Args(makeException(err)).Rets(err),
+		Args(err).Rets(err),
+		Args(makeException(err)).Rets(err),
 	})
 }
 
@@ -33,10 +33,10 @@ func TestException(t *testing.T) {
 		Hash(hash.Pointer(unsafe.Pointer(reflect.ValueOf(exc).Pointer()))).
 		Equal(exc).
 		NotEqual(makeException(errors.New("error"))).
-		AllKeys("reason").
+		AllKeys("reason", "stack-trace").
 		Index("reason", err).
 		IndexError("stack", vals.NoSuchKey("stack")).
-		Repr("[&reason=[&content=error &type=fail]]")
+		Repr("[&reason=[&content=error &type=fail] &stack-trace=<...>]")
 
 	vals.TestValue(t, OK).
 		Kind("exception").
@@ -45,7 +45,16 @@ func TestException(t *testing.T) {
 }
 
 func makeException(cause error, entries ...*diag.Context) Exception {
-	return NewException(cause, MakeStackTrace(entries...))
+	return NewException(cause, makeStackTrace(entries...))
+}
+
+// Creates a new StackTrace, using the first entry as the head.
+func makeStackTrace(entries ...*diag.Context) *StackTrace {
+	var s *StackTrace
+	for i := len(entries) - 1; i >= 0; i-- {
+		s = &StackTrace{Head: entries[i], Next: s}
+	}
+	return s
 }
 
 func TestFlow_Fields(t *testing.T) {
@@ -69,7 +78,7 @@ func TestExternalCmdExit_Fields(t *testing.T) {
 func TestPipelineError_Fields(t *testing.T) {
 	Test(t,
 		That("put ?(fail 1 | fail 2)[reason][type]").Puts("pipeline"),
-		That("count ?(fail 1 | fail 2)[reason][exceptions]").Puts("2"),
+		That("count ?(fail 1 | fail 2)[reason][exceptions]").Puts(2),
 		That("put ?(fail 1 | fail 2)[reason][exceptions][0][reason][type]").
 			Puts("fail"),
 	)
@@ -77,15 +86,15 @@ func TestPipelineError_Fields(t *testing.T) {
 
 func TestErrorMethods(t *testing.T) {
 	tt.Test(t, tt.Fn("Error", error.Error), tt.Table{
-		tt.Args(makeException(errors.New("err"))).Rets("err"),
+		Args(makeException(errors.New("err"))).Rets("err"),
 
-		tt.Args(MakePipelineError([]Exception{
+		Args(MakePipelineError([]Exception{
 			makeException(errors.New("err1")),
 			makeException(errors.New("err2"))})).Rets("(err1 | err2)"),
 
-		tt.Args(Return).Rets("return"),
-		tt.Args(Break).Rets("break"),
-		tt.Args(Continue).Rets("continue"),
-		tt.Args(Flow(1000)).Rets("!(BAD FLOW: 1000)"),
+		Args(Return).Rets("return"),
+		Args(Break).Rets("break"),
+		Args(Continue).Rets("continue"),
+		Args(Flow(1000)).Rets("!(BAD FLOW: 1000)"),
 	})
 }
