@@ -2,6 +2,7 @@ package eval_test
 
 import (
 	"os"
+	"os/exec"
 	"testing"
 
 	. "src.elv.sh/pkg/eval"
@@ -15,13 +16,13 @@ func TestBuiltinFnExternal(t *testing.T) {
 	testutil.Setenv(t, "PATH", tmpHome+":"+os.Getenv("PATH"))
 
 	Test(t,
-		That(`e = (external true); kind-of $e`).Puts("fn"),
-		That(`e = (external true); put (repr $e)`).Puts("<external true>"),
-		That(`e = (external false); m = [&$e=true]; put (repr $m)`).Puts("[&<external false>=true]"),
+		That("var e = (external true); kind-of $e").Puts("fn"),
+		That("var e = (external true); put (repr $e)").Puts("<external true>"),
+		That("var e = (external false); var m = [&$e=true]; put (repr $m)").Puts("[&<external false>=true]"),
 		// Test calling of external commands.
-		That(`e = (external true); $e`).DoesNothing(),
-		That(`e = (external true); $e &option`).Throws(ErrExternalCmdOpts, "$e &option"),
-		That(`e = (external false); $e`).Throws(CmdExit(
+		That("var e = (external true); $e").DoesNothing(),
+		That("var e = (external true); $e &option").Throws(ErrExternalCmdOpts, "$e &option"),
+		That("var e = (external false); $e").Throws(CmdExit(
 			ExternalCmdExit{CmdName: "false", WaitStatus: exitWaitStatus(1)})),
 
 		// TODO: Modify the ExternalCmd.Call method to wrap the Go error in a
@@ -30,6 +31,7 @@ func TestBuiltinFnExternal(t *testing.T) {
 		//
 		// The command shouldn't be found when run so we should get an
 		// exception along the lines of "executable file not found in $PATH".
-		That(`e = (external true); E:PATH=/ $e`).Throws(AnyError),
+		That("var e = (external true); { tmp E:PATH = /; $e }").
+			Throws(ErrorWithType(&exec.Error{})),
 	)
 }
