@@ -1,5 +1,4 @@
 //go:build windows
-// +build windows
 
 package eval_test
 
@@ -8,5 +7,5 @@ import (
 )
 
 func exitWaitStatus(exit uint32) syscall.WaitStatus {
-	return syscall.WaitStatus{exit}
+	return syscall.WaitStatus{ExitCode: exit}
 }
