@@ -1,6 +1,3 @@
-//go:build go1.18
-// +build go1.18
-
 package eval
 
 import (
@@ -14,6 +11,6 @@ func FuzzCheck(f *testing.F) {
 	f.Add("put $x")
 	f.Add("put foo bar | each {|x| echo $x }")
 	f.Fuzz(func(t *testing.T, code string) {
-		NewEvaler().Check(parse.Source{Name: "fuzz", Code: code}, nil)
+		NewEvaler().Check(parse.Source{Name: "[fuzz]", Code: code}, nil)
 	})
 }
