@@ -1,20 +1,21 @@
 package vals
 
 import (
+	"math/big"
 	"os"
 	"testing"
 
-	. "github.com/elves/elvish/pkg/tt"
+	"src.elv.sh/pkg/tt"
 )
 
 type customEqualer struct{ ret bool }
 
-func (c customEqualer) Equal(interface{}) bool { return c.ret }
+func (c customEqualer) Equal(any) bool { return c.ret }
 
 type customStruct struct{ a, b string }
 
 func TestEqual(t *testing.T) {
-	Test(t, Fn("Equal", Equal), Table{
+	tt.Test(t, tt.Fn("Equal", Equal), tt.Table{
 		Args(nil, nil).Rets(true),
 		Args(nil, "").Rets(false),
 
@@ -22,6 +23,15 @@ func TestEqual(t *testing.T) {
 		Args(true, false).Rets(false),
 
 		Args(1.0, 1.0).Rets(true),
+		Args(1.0, 1.1).Rets(false),
+		Args("1.0", 1.0).Rets(false),
+		Args(1, 1.0).Rets(false),
+		Args(1, 1).Rets(true),
+		Args(bigInt(z), bigInt(z)).Rets(true),
+		Args(bigInt(z), 1).Rets(false),
+		Args(bigInt(z), bigInt(z1)).Rets(false),
+		Args(big.NewRat(1, 2), big.NewRat(1, 2)).Rets(true),
+		Args(big.NewRat(1, 2), 0.5).Rets(false),
 
 		Args("lorem", "lorem").Rets(true),
 		Args("lorem", "ipsum").Rets(false),
