@@ -6,7 +6,7 @@ import (
 	"os"
 	"testing"
 
-	. "src.elv.sh/pkg/tt"
+	"src.elv.sh/pkg/tt"
 )
 
 type reprer struct{}
@@ -15,10 +15,8 @@ func (reprer) Repr(int) string { return "<reprer>" }
 
 type nonReprer struct{}
 
-func repr(a interface{}) string { return Repr(a, NoPretty) }
-
-func TestRepr(t *testing.T) {
-	Test(t, Fn("repr", repr), Table{
+func TestReprPlain(t *testing.T) {
+	tt.Test(t, tt.Fn("ReprPlain", ReprPlain), tt.Table{
 		Args(nil).Rets("$nil"),
 
 		Args(false).Rets("$false"),
