@@ -6,6 +6,8 @@ import (
 	"src.elv.sh/pkg/tt"
 )
 
+var Args = tt.Args
+
 func TestBlackhole(t *testing.T) {
 	v := NewBlackhole()
 	err := v.Set("foo")
@@ -20,7 +22,7 @@ func TestBlackhole(t *testing.T) {
 
 func TestIsBlackhole(t *testing.T) {
 	tt.Test(t, tt.Fn("IsBlackhole", IsBlackhole), tt.Table{
-		tt.Args(NewBlackhole()).Rets(true),
-		tt.Args(FromInit("")).Rets(false),
+		Args(NewBlackhole()).Rets(true),
+		Args(FromInit("")).Rets(false),
 	})
 }
