@@ -85,7 +85,7 @@ func TestStr(t *testing.T) {
 
 		That(`str:join : [/usr /bin /tmp]`).Puts("/usr:/bin:/tmp"),
 		That(`str:join : ['' a '']`).Puts(":a:"),
-		That(`str:join : [(float64 1) 2]`).Throws(
+		That(`str:join : [(num 1) 2]`).Throws(
 			errs.BadValue{What: "input to str:join", Valid: "string", Actual: "number"}),
 
 		That(`str:last-index abc`).Throws(ErrorWithType(errs.ArityMismatch{})),
@@ -97,17 +97,17 @@ func TestStr(t *testing.T) {
 
 		That(`str:split : /usr:/bin:/tmp`).Puts("/usr", "/bin", "/tmp"),
 		That(`str:split : /usr:/bin:/tmp &max=2`).Puts("/usr", "/bin:/tmp"),
-		That(`str:split : a:b >&-`).Throws(eval.ErrNoValueOutput),
+		That(`str:split : a:b >&-`).Throws(eval.ErrPortDoesNotSupportValueOutput),
 
 		That(`str:to-codepoints a`).Puts("0x61"),
 		That(`str:to-codepoints 你好`).Puts("0x4f60", "0x597d"),
 		That(`str:to-codepoints 你好 | str:from-codepoints (all)`).Puts("你好"),
-		That(`str:to-codepoints a >&-`).Throws(eval.ErrNoValueOutput),
+		That(`str:to-codepoints a >&-`).Throws(eval.ErrPortDoesNotSupportValueOutput),
 
 		That(`str:to-utf8-bytes a`).Puts("0x61"),
 		That(`str:to-utf8-bytes 你好`).Puts("0xe4", "0xbd", "0xa0", "0xe5", "0xa5", "0xbd"),
 		That(`str:to-utf8-bytes 你好 | str:from-utf8-bytes (all)`).Puts("你好"),
-		That(`str:to-utf8-bytes a >&-`).Throws(eval.ErrNoValueOutput),
+		That(`str:to-utf8-bytes a >&-`).Throws(eval.ErrPortDoesNotSupportValueOutput),
 
 		That(`str:title abc`).Puts("Abc"),
 		That(`str:title "abc def"`).Puts("Abc Def"),
