@@ -1,5 +1,4 @@
 //go:build !windows && !plan9 && !js
-// +build !windows,!plan9,!js
 
 package unix
 
@@ -13,6 +12,6 @@ var (
 	ErrorWithMessage = evaltest.ErrorWithMessage
 )
 
-func useUNIX(ev *eval.Evaler) {
+func useUnix(ev *eval.Evaler) {
 	ev.ExtendGlobal(eval.BuildNs().AddNs("unix", Ns))
 }
