@@ -10,7 +10,7 @@ import (
 // Primary returns a primary node and true if that's the only child of the
 // compound node. Otherwise it returns nil and false.
 func Primary(n *parse.Compound) (*parse.Primary, bool) {
-	if len(n.Indexings) == 1 && len(n.Indexings[0].Indices) == 0 {
+	if n != nil && len(n.Indexings) == 1 && len(n.Indexings[0].Indices) == 0 {
 		return n.Indexings[0].Head, true
 	}
 	return nil, false
