@@ -3,17 +3,24 @@ package shell
 import (
 	"testing"
 
+	"src.elv.sh/pkg/must"
 	. "src.elv.sh/pkg/prog/progtest"
 	"src.elv.sh/pkg/testutil"
 )
 
 func TestScript(t *testing.T) {
+	setupCleanHomePaths(t)
 	testutil.InTempDir(t)
-	testutil.MustWriteFile("a.elv", "echo hello")
+	must.WriteFile("hello.elv", "echo hello")
+	must.WriteFile("invalid-utf8.elv", "\xff")
 
 	Test(t, &Program{},
-		ThatElvish("a.elv").WritesStdout("hello\n"),
+		ThatElvish("hello.elv").WritesStdout("hello\n"),
 		ThatElvish("-c", "echo hello").WritesStdout("hello\n"),
+
+		ThatElvish("invalid-utf8.elv").
+			ExitsWith(2).
+			WritesStderrContaining("cannot read script"),
 		ThatElvish("non-existent.elv").
 			ExitsWith(2).
 			WritesStderrContaining("cannot read script"),
@@ -21,8 +28,12 @@ func TestScript(t *testing.T) {
 		// parse error
 		ThatElvish("-c", "echo [").
 			ExitsWith(2).
-			WritesStderrContaining("parse error"),
+			WritesStderrContaining("Parse error"),
 		// parse error with -compileonly
+		ThatElvish("-compileonly", "-c", "echo [").
+			ExitsWith(2).
+			WritesStderrContaining("Parse error"),
+		// parse error with -compileonly -json
 		ThatElvish("-compileonly", "-json", "-c", "echo [").
 			ExitsWith(2).
 			WritesStdout(`[{"fileName":"code from -c","start":6,"end":6,"message":"should be ']'"}]`+"\n"),
@@ -34,8 +45,12 @@ func TestScript(t *testing.T) {
 		// compilation error
 		ThatElvish("-c", "echo $a").
 			ExitsWith(2).
-			WritesStderrContaining("compilation error"),
+			WritesStderrContaining("Compilation error"),
 		// compilation error with -compileonly
+		ThatElvish("-compileonly", "-c", "echo $a").
+			ExitsWith(2).
+			WritesStderrContaining("Compilation error"),
+		// compilation error with -compileonly -json
 		ThatElvish("-compileonly", "-json", "-c", "echo $a").
 			ExitsWith(2).
 			WritesStdout(`[{"fileName":"code from -c","start":5,"end":7,"message":"variable $a not found"}]`+"\n"),
