@@ -5,8 +5,9 @@ import (
 	"sync"
 	"time"
 
-	"github.com/elves/elvish/pkg/logutil"
 	bolt "go.etcd.io/bbolt"
+	"src.elv.sh/pkg/logutil"
+	. "src.elv.sh/pkg/store/storedefs"
 )
 
 var logger = logutil.GetLogger("[store] ")
@@ -14,21 +15,18 @@ var initDB = map[string](func(*bolt.Tx) error){}
 
 // DBStore is the permanent storage backend for elvish. It is not thread-safe.
 // In particular, the store may be closed while another goroutine is still
-// accessing the  To prevent bad things from happening, every time the
+// accessing the store. To prevent bad things from happening, every time the
 // main goroutine spawns a new goroutine to operate on the store, it should call
-// Waits.Add(1) in the main goroutine before spawning another goroutine, and
-// call Waits.Done() in the spawned goroutine after the operation is finished.
+// wg.Add(1) in the main goroutine before spawning another goroutine, and
+// call wg.Done() in the spawned goroutine after the operation is finished.
 type DBStore interface {
 	Store
-
-	Waits() *sync.WaitGroup
 	Close() error
 }
 
 type dbStore struct {
 	db *bolt.DB
-	// Waits is used for registering outstanding operations on the
-	waits sync.WaitGroup
+	wg sync.WaitGroup // used for registering outstanding operations on the store
 }
 
 func dbWithDefaultOptions(dbname string) (*bolt.DB, error) {
@@ -53,8 +51,8 @@ func NewStoreFromDB(db *bolt.DB) (DBStore, error) {
 	logger.Println("initializing store")
 	defer logger.Println("initialized store")
 	st := &dbStore{
-		db:    db,
-		waits: sync.WaitGroup{},
+		db: db,
+		wg: sync.WaitGroup{},
 	}
 
 	err := db.Update(func(tx *bolt.Tx) error {
@@ -69,18 +67,12 @@ func NewStoreFromDB(db *bolt.DB) (DBStore, error) {
 	return st, err
 }
 
-// Waits returns a WaitGroup used to register outstanding storage requests when
-// making calls asynchronously.
-func (s *dbStore) Waits() *sync.WaitGroup {
-	return &s.waits
-}
-
 // Close waits for all outstanding operations to finish, and closes the
 // database.
 func (s *dbStore) Close() error {
 	if s == nil || s.db == nil {
 		return nil
 	}
-	s.waits.Wait()
+	s.wg.Wait()
 	return s.db.Close()
 }
