@@ -8,29 +8,29 @@ func TestStyleSGR(t *testing.T) {
 	// Test the SGR sequences of style attributes indirectly via VTString of
 	// Text, since that is how they are used.
 	testTextVTString(t, []textVTStringTest{
-		{T("foo", Bold), "\033[1mfoo\033[m"},
-		{T("foo", Dim), "\033[2mfoo\033[m"},
-		{T("foo", Italic), "\033[3mfoo\033[m"},
-		{T("foo", Underlined), "\033[4mfoo\033[m"},
-		{T("foo", Blink), "\033[5mfoo\033[m"},
-		{T("foo", Inverse), "\033[7mfoo\033[m"},
-		{T("foo", FgRed), "\033[31mfoo\033[m"},
-		{T("foo", BgRed), "\033[41mfoo\033[m"},
-		{T("foo", Bold, FgRed, BgBlue), "\033[1;31;44mfoo\033[m"},
+		{T("foo", Bold), "\033[;1mfoo\033[m"},
+		{T("foo", Dim), "\033[;2mfoo\033[m"},
+		{T("foo", Italic), "\033[;3mfoo\033[m"},
+		{T("foo", Underlined), "\033[;4mfoo\033[m"},
+		{T("foo", Blink), "\033[;5mfoo\033[m"},
+		{T("foo", Inverse), "\033[;7mfoo\033[m"},
+		{T("foo", FgRed), "\033[;31mfoo\033[m"},
+		{T("foo", BgRed), "\033[;41mfoo\033[m"},
+		{T("foo", Bold, FgRed, BgBlue), "\033[;1;31;44mfoo\033[m"},
 	})
 }
 
 type mergeFromOptionsTest struct {
 	style     Style
-	options   map[string]interface{}
+	options   map[string]any
 	wantStyle Style
 	wantErr   string
 }
 
 var mergeFromOptionsTests = []mergeFromOptionsTest{
 	// Parsing of each possible key.
-	kv("fg-color", "red", Style{Foreground: Red}),
-	kv("bg-color", "red", Style{Background: Red}),
+	kv("fg-color", "red", Style{Fg: Red}),
+	kv("bg-color", "red", Style{Bg: Red}),
 	kv("bold", true, Style{Bold: true}),
 	kv("dim", true, Style{Dim: true}),
 	kv("italic", true, Style{Italic: true}),
@@ -40,32 +40,32 @@ var mergeFromOptionsTests = []mergeFromOptionsTest{
 	// Merging with existing options.
 	{
 		style: Style{Bold: true, Dim: true},
-		options: map[string]interface{}{
+		options: map[string]any{
 			"bold": false, "fg-color": "red",
 		},
-		wantStyle: Style{Dim: true, Foreground: Red},
+		wantStyle: Style{Dim: true, Fg: Red},
 	},
 	// Bad key.
 	{
-		options: map[string]interface{}{"bad": true},
+		options: map[string]any{"bad": true},
 		wantErr: "unrecognized option 'bad'",
 	},
 	// Bad type for color field.
 	{
-		options: map[string]interface{}{"fg-color": true},
+		options: map[string]any{"fg-color": true},
 		wantErr: "value for option 'fg-color' must be a valid color string",
 	},
 	// Bad type for bool field.
 	{
-		options: map[string]interface{}{"bold": ""},
+		options: map[string]any{"bold": ""},
 		wantErr: "value for option 'bold' must be a bool value",
 	},
 }
 
 // A helper for constructing a test case whose input is a single key-value pair.
-func kv(k string, v interface{}, s Style) mergeFromOptionsTest {
+func kv(k string, v any, s Style) mergeFromOptionsTest {
 	return mergeFromOptionsTest{
-		options: map[string]interface{}{k: v}, wantStyle: s,
+		options: map[string]any{k: v}, wantStyle: s,
 	}
 }
 
