@@ -1,21 +1,36 @@
 package ui
 
 import (
+	"errors"
 	"testing"
 
 	"src.elv.sh/pkg/eval/vals"
 	"src.elv.sh/pkg/tt"
 )
 
-var Args = tt.Args
-
 func TestT(t *testing.T) {
 	tt.Test(t, tt.Fn("T", T), tt.Table{
 		Args("test").Rets(Text{&Segment{Text: "test"}}),
 		Args("test red", FgRed).Rets(Text{&Segment{
-			Text: "test red", Style: Style{Foreground: Red}}}),
+			Text: "test red", Style: Style{Fg: Red}}}),
 		Args("test red", FgRed, Bold).Rets(Text{&Segment{
-			Text: "test red", Style: Style{Foreground: Red, Bold: true}}}),
+			Text: "test red", Style: Style{Fg: Red, Bold: true}}}),
+	})
+}
+
+func TestConcat(t *testing.T) {
+	tt.Test(t, tt.Fn("Concat", Concat), tt.Table{
+		Args().Rets(Text(nil)),
+		Args(T("red", FgRed), T("blue", FgBlue), T("green", FgGreen)).
+			Rets(Text{red("red"), blue("blue"), green("green")}),
+		// Merging adjacent segments with the same style
+		Args(T("red", FgRed), T("red", FgRed)).Rets(T("redred", FgRed)),
+		// Concatenating texts with multiple segments
+		Args(Concat(T("red", FgRed), T("blue", FgBlue)),
+			Concat(T("blue", FgBlue), T("green", FgGreen))).
+			Rets(Text{red("red"), blue("blueblue"), green("green")}),
+		// Concatenating empty texts
+		Args(T(""), T("red", FgRed), T("")).Rets(T("red", FgRed)),
 	})
 }
 
@@ -24,7 +39,11 @@ func TestTextAsElvishValue(t *testing.T) {
 		Kind("ui:text").
 		Repr("(ui:text text)").
 		AllKeys("0").
-		Index("0", &Segment{Text: "text"})
+		Index("0", &Segment{Text: "text"}).
+		IndexError("a", errors.New("index must be integer"))
+
+	vals.TestValue(t, Concat(T("red", FgRed), T("blue", FgBlue), T("green", FgGreen))).
+		Index("0..2", Concat(T("red", FgRed), T("blue", FgBlue)))
 
 	vals.TestValue(t, T("text", FgRed)).
 		Repr("(ui:text (ui:text-segment text &fg-color=red))")
@@ -38,9 +57,6 @@ var (
 	text2 = Text{red("lorem"), blue("foobar")}
 )
 
-func red(s string) *Segment  { return &Segment{Style{Foreground: Red}, s} }
-func blue(s string) *Segment { return &Segment{Style{Foreground: Blue}, s} }
-
 var partitionTests = tt.Table{
 	Args(text0).Rets([]Text{nil}),
 	Args(text1).Rets([]Text{text1}),
@@ -120,6 +136,11 @@ func TestSplitByRune(t *testing.T) {
 				{blue("s")},
 				{blue("um"), red("dolar")},
 			}),
+		Args(Text{red("lorem\n")}, '\n').Rets(
+			[]Text{
+				{red("lorem")},
+				nil,
+			}),
 	})
 }
 
@@ -141,6 +162,7 @@ type textVTStringTest struct {
 }
 
 func testTextVTString(t *testing.T, tests []textVTStringTest) {
+	t.Helper()
 	for _, test := range tests {
 		vtString := test.text.VTString()
 		if vtString != test.wantVTString {
@@ -148,3 +170,7 @@ func testTextVTString(t *testing.T, tests []textVTStringTest) {
 		}
 	}
 }
+
+func red(s string) *Segment   { return &Segment{Style{Fg: Red}, s} }
+func blue(s string) *Segment  { return &Segment{Style{Fg: Blue}, s} }
+func green(s string) *Segment { return &Segment{Style{Fg: Green}, s} }
